@@ -19,9 +19,9 @@ def about(lang, name):
 	content = source_code.content
 	soup = BeautifulSoup(content, features="html.parser")
 
-	info = soup.find('div', {'class': 'pure-1 md-3-5'})
+	info = soup.find_all('div', {'class': 'pure-1 md-3-5'})
 	if info:
-		ttext = info.find('p').getText()
+		ttext = info.find_all('p').getText()
 		return translate(lang, ttext)
 
 def episodes(name):
